import math, pygame, data

def rect(c, r):
    """Enter a center and a radius of offset. 
    Will return the pointlist for a rectangle. 
    Center and Radius must both be 2-tuples or Euclid Vectors etc.."""
    
    ret=[[c[0]-r[0],c[1]-r[1]],
            [c[0]+r[0],c[1]-r[1]],
            [c[0]+r[0],c[1]+r[1]],
            [c[0]-r[0],c[1]+r[1]]]
            
    return ret
            
def tri(c,bh):
    """Enter a center and base-height. 
    Returns a pointlist for a triangle."""
    
    return [
            [c[0]           ,c[1]-bh[1]],
            [c[0]+bh[0],c[1]+bh[1]          ],
            [c[0]-bh[0],c[1]+bh[1]           ]]
 

def lerp(a,b,p=0.7):
    """Blend two colors with a certain percentage of the old"""
    newcolor=[0,0,0]
    for i in range(3):
        newcolor[i]=int(a[i]*p+b[i]*(1-p))
    return newcolor

def norm(x):
    """Converts to goups of numbers to ints before being sent to pygame.draw"""
    return [int(y) for y in x]

def  rectcollide(c,r,cc,rr):
    if abs(c[0]-cc[0])<=(r[0]+rr[0]) and abs(c[1]-cc[1])<=(r[1]+rr[1]):
        return True
    else:
        return False

def rot(points,angle,center=[400,300]):
    return [ 
            [math.cos(angle)*(p[0]-center[0])-math.sin(angle)*(p[1]-center[1]),
            math.sin(angle)*(p[0]-center[0])+math.cos(angle)*(p[1]-center[1])]for p in points]

def translate(points,center):
    return [ [p[0]+center[0],p[1]+center[1]] for p in points]
    
def cward(c,r,cc,rr):
    dist2=(c[0]-cc[0])**2+(c[1]-cc[1])**2
    if dist2<(r[0]**2+rr[0]**2):
        return (0,0)
    else:
        a=math.atan2((c[1]-cc[1]),(c[0]-cc[0]))
        return(math.cos(a),math.sin(a))
    
def dot(v, w):
    return v[0]*w[0] + v[1]*w[1]

class NoneSound:
        def play(self,num=1): pass
        def stop():pass

def load_sound(name):
    if not pygame.mixer:
        return NoneSound()
    fullname = data.filepath(name)
    try:
        sound = pygame.mixer.Sound(fullname)
    except pygame.error, message:
        print 'Cannot load sound:', name
        raise SystemExit, message
    return sound